@@ -1,8 +1,13 @@
-package Search::Elasticsearch::Client::5_0::Async::Bulk;
-$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '6.80_01'; # TRIAL
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
 
-$Search::Elasticsearch::Client::5_0::Async::Bulk::VERSION = '6.8001';use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
+package Search::Elasticsearch::Client::6_0::Async::Bulk;
+$Search::Elasticsearch::Client::6_0::Async::Bulk::VERSION = '7.30_1'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Async::Bulk::VERSION = '7.301';
+use Moo;
+with 'Search::Elasticsearch::Client::6_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -124,11 +129,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Async::Bulk - A helper module for the Bulk API
+Search::Elasticsearch::Client::6_0::Async::Bulk - A helper module for the Bulk API
 
 =head1 VERSION
 
-version 6.80_01
+version 7.30_1
 
 =head1 SYNOPSIS
 
@@ -163,18 +168,18 @@ version 6.80_01
 
 =head1 DESCRIPTION
 
-This module provides an async wrapper for the L<Search::Elasticsearch::Client::5_0::Direct/bulk()>
+This module provides an async wrapper for the L<Search::Elasticsearch::Client::6_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request.
 
-The L<Search::Elasticsearch::Client::5_0::Async::Bulk> module acts as a queue, buffering up actions
+The L<Search::Elasticsearch::Client::6_0::Async::Bulk> module acts as a queue, buffering up actions
 until it reaches a maximum count of actions, or a maximum size of JSON request
 body, at which point it issues a C<bulk()> request.
 
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
-This class does L<Search::Elasticsearch::Client::5_0::Role::Bulk> and
+This class does L<Search::Elasticsearch::Client::6_0::Role::Bulk> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 CREATING A NEW INSTANCE
@@ -189,7 +194,7 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
         max_count   => 1_000,               # optional
         max_size    => 1_000_000,           # optional
-        max_time    => 5,                   # optional
+        max_time    => 6,                   # optional
 
         verbose     => 0 | 1,               # optional
 
@@ -200,13 +205,13 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
     );
 
-The C<bulk_helper> method loads L<Search::Elasticsearch::Client::5_0::Async::Bulk>,
+The C<bulk_helper> method loads L<Search::Elasticsearch::Client::6_0::Async::Bulk>,
 calls L</new()> with the specified parameters and returns a new C<$bulk> object.
 
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::6_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -217,7 +222,7 @@ See L</flush()> for more information about the other parameters.
     $promise = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> request and returns
+a L<bulk()|Search::Elasticsearch::Client::6_0::Direct/bulk()> request and returns
 a L<Promise>, which is rejected if the bulk request fails or if any of
 the C<on_success>, C<on_error> or C<on_conflict> callbacks throws an
 exception, otherwise it is resolved with the items that have been flushed.
@@ -423,7 +428,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -449,7 +454,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -462,7 +467,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -487,11 +492,11 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above). More information on C<script> can be found here:
-L<Search::Elasticsearch::Client::5_0::Direct/update()>.
+L<Search::Elasticsearch::Client::6_0::Direct/update()>.
 
 =head1 AUTHOR
 
