@@ -1,5 +1,22 @@
-package Search::Elasticsearch::Client::5_0::Async::Scroll;
-$Search::Elasticsearch::Client::5_0::Async::Scroll::VERSION = '6.80';
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
+package Search::Elasticsearch::Client::6_0::Async::Scroll;
+$Search::Elasticsearch::Client::6_0::Async::Scroll::VERSION = '7.715';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Search::Elasticsearch::Async::Util qw(thenable);
@@ -14,7 +31,7 @@ has 'on_error'      => ( is => 'lazy', clearer => '_clear_on_error' );
 has '_guard'        => ( is => 'rwp', clearer => '_clear__guard' );
 
 with 'Search::Elasticsearch::Role::Is_Async',
-    'Search::Elasticsearch::Client::5_0::Role::Scroll';
+    'Search::Elasticsearch::Client::6_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -83,7 +100,11 @@ sub _first_results {
 #===================================
     my ( $self, $results ) = @_;
 
-    my $total = $self->_set_total( $results->{hits}{total} );
+    my $total = $results->{hits}{total};
+    if (ref $total) {
+        $total = $total->{value};
+    }
+    $self->_set_total($total);
     $self->_set_max_score( $results->{hits}{max_score} );
     $self->_set_aggregations( $results->{aggregations} );
     $self->_set_facets( $results->{facets} );
@@ -191,7 +212,7 @@ sub finish {
     my %args
         = $self->scroll_in_qs
         ? ( scroll_id => $scroll_id )
-        : ( body => { scroll_id => [$scroll_id] } );
+        : ( body => { scroll_id => $scroll_id } );
 
     $self->es->clear_scroll(%args)->then(
         sub {
@@ -215,11 +236,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Async::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::6_0::Async::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 6.80
+version 7.715
 
 =head1 SYNOPSIS
 
@@ -270,17 +291,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::5_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::5_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::6_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::6_0::Direct/scroll()> methods to make
 them easier to use.
 
-This class does L<Search::Elasticsearch::Client::5_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::6_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 USE CASES
@@ -359,7 +380,7 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-do this is to use the built-in L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+do this is to use the built-in L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
 functionality provided by Elasticsearch.
 
 =head1 METHODS
@@ -382,14 +403,14 @@ functionality provided by Elasticsearch.
     );
     $scroll->start;
 
-The L<Search::Elasticsearch::Client::5_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::5_0::Async::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::6_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::6_0::Async::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">),
 C<scroll_in_qs> (which defaults to C<false>), and any
 of the listed callbacks. Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::5_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::6_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -398,7 +419,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::5_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::6_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -475,7 +496,7 @@ or rejected if any errors remain unhandled.
 
 The C<finish()> method clears out the buffer, sets L</is_finished()> to C<true>
 and tries to clear the C<scroll_id> on Elasticsearch.  This API is only
-supported since v0.90.5, but the call to C<clear_scroll> is wrapped in an
+supported since v0.90.6, but the call to C<clear_scroll> is wrapped in an
 C<eval> so the C<finish()> method can be safely called with any version
 of Elasticsearch.
 
@@ -527,9 +548,9 @@ This value can only be checked once the scroll has completed.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::5_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::6_0::Direct/scroll()>
 
 =back
 
@@ -539,7 +560,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2021 by Elasticsearch BV.
 
 This is free software, licensed under:
 
